/* src/math1/rfalib/rstd0.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
doublereal rstd0_(real *rx, integer *n, integer *jx)
{
    /* System generated locals */
    integer i__1, i__2;
    real ret_val, r__1;

    /* Builtin functions */
    double sqrt(doublereal);

    /* Local variables */
    static integer i__;
    static real ave, sum;
    extern doublereal rave0_(real *, integer *, integer *);

    /* Parameter adjustments */
    --rx;

    /* Function Body */
    ave = rave0_(&rx[1], n, jx);
    sum = 0.f;
    i__1 = *jx * (*n - 1) + 1;
    i__2 = *jx;
    for (i__ = 1; i__2 < 0 ? i__ >= i__1 : i__ <= i__1; i__ += i__2) {
/* Computing 2nd power */
	r__1 = rx[i__] - ave;
	sum += r__1 * r__1;
/* L10: */
    }
    ret_val = sqrt(sum / *n);
    return ret_val;
} /* rstd0_ */

